{%- set footer_content = get_part('global footer') %}
{% extends "base_templates/base.html" %}

{% block main %}

{%- if special_error %}
{{ special_error|safe }}
{%- else %}
<h1>{{ word('Error') }}</h1>
{%- endif %}

{%- if show_retry %}
<p><a href="#" id="da-retry">{{ word('Retry') }}</a></p>

{%- endif %}
{%- if verbose %}
{{ error|safe }}

{%- if show_debug and historytext != 'None' %}

<h3>{{ word('History') }}</h3>

{{ historytext | safe }}

  {%- if yaml_filename %}
<p><a target="_blank" href="{{ url_for('get_variables', i=yaml_filename) }}">{{ word('Show variables and values') }}</a></p>
  {%- endif %}
{%- endif %}

{%- if show_debug and logtext != 'None' %}

<h3>{{ word('Log') }}</h3>

<pre>{{ logtext }}</pre>

{%- endif %}
{%- endif %}

{% endblock %}
