{% extends 'flask_user/emails/base_message.html' %}

{% block message %}
<p>{{ word('Your username has been changed.') }}</p>
<p>{{ word('If you did not initiate this username change, please') }} <a href="{{ url_for('user.login', _external=True) }}">{{ word('sign in') }}</a> {{ word('(using your email address) and change your password.') }}</p>
{% endblock %}
