{% extends 'base_templates/flask_wide_base.html' %}

{% block content %}
{% from "base_templates/form_macros.html" import render_field, render_file_field, render_submit_field with context %}
<h1>{{ word('Restart') }}</h1>
<p>{{ word('Please wait.  System is restarting.') }}</p>
{% endblock %}
