{% extends "base_templates/base.html" %}
{% block main %}
      <div class="row">
        <div class="col-lg-9">
          {%- if version_warning and current_user.has_roles(['admin', 'developer']) %}
          <div class="alert alert-danger">
            {{ version_warning }}
          </div>
          {%- endif %}
          {%- block content %}{% endblock %}
        </div>
      </div>
{%- endblock %}
