{% extends 'base_templates/page_base_half.html' %}

{% block content %}
{% from "base_templates/form_macros.html" import render_field, render_submit_field %}

<form action="" method="POST" role="form">
  {{ form.hidden_tag() }}
  {{ render_field(form.name) }}
  {{ render_submit_field(form.submit) }}
  <a class="btn {{ config['BUTTON_STYLE'] }}secondary {{ config['BUTTON_CLASS'] }}" href="{{ url_for('privilege_list') }}">{{ word('Back') }}</a>

</form>

{% endblock %}
